@@ -12,6 +12,8 @@
  *      See readme.txt for copyright information.
  */
 
+#define ALLEGRO_INTERNAL_UNSTABLE
+
 #include <string.h>
 #include "allegro5/allegro.h"
 #include "allegro5/allegro_font.h"
@@ -36,7 +38,7 @@ typedef struct
 
 /* globals */
 static bool font_inited = false;
-static _AL_VECTOR font_handlers;
+static _AL_VECTOR font_handlers = _AL_VECTOR_INITIALIZER(FONT_HANDLER);
 
 
 /* al_font_404_character:
@@ -291,7 +293,7 @@ static int color_get_font_ranges(ALLEGRO_FONT *font, int ranges_count,
 
 static bool color_get_glyph_dimensions(ALLEGRO_FONT const *f,
    int codepoint, int *bbx, int *bby, int *bbw, int *bbh)
-{   
+{
    ALLEGRO_BITMAP *glyph = _al_font_color_find_glyph(f, codepoint);
    if(!glyph) {
       if (f->fallback) {
@@ -311,15 +313,15 @@ static int color_get_glyph_advance(ALLEGRO_FONT const *f,
    int codepoint1, int codepoint2)
 {
    (void) codepoint2;
-   
+
    /* Handle special case to simplify use in a loop. */
    if (codepoint1 == ALLEGRO_NO_KERNING) {
       return 0;
    }
-      
-   /* For other cases, bitmap fonts don't use any kerning, so just use the 
+
+   /* For other cases, bitmap fonts don't use any kerning, so just use the
     * width of codepoint1. */
-    
+
    return color_char_length(f, codepoint1);
 }
 
@@ -369,8 +371,6 @@ bool al_init_font_addon(void)
       return true;
    }
 
-   _al_vector_init(&font_handlers, sizeof(FONT_HANDLER));
-
    al_register_font_loader(".bmp", _al_load_bitmap_font);
    al_register_font_loader(".jpg", _al_load_bitmap_font);
    al_register_font_loader(".pcx", _al_load_bitmap_font);
