@@ -53,16 +53,16 @@ static void ensure_trailing_slash(ALLEGRO_USTR *us)
    }
 }
 
-ALLEGRO_USTR *_al_physfs_apply_cwd(const char *path)
+ALLEGRO_USTR *_al_physfs_process_path(const char *path)
 {
    ALLEGRO_USTR *us;
-
-   if (path_is_absolute(path)) {
-      return al_ustr_new(path);
-   }
-
-   us = al_ustr_new(fs_phys_cwd);
-   al_ustr_append_cstr(us, path);
+   ALLEGRO_PATH *p = al_create_path(path);
+   ALLEGRO_PATH *cwd = al_create_path(fs_phys_cwd);
+   al_rebase_path(cwd, p);
+   al_destroy_path(cwd);
+   /* PHYSFS always uses / separator. */
+   us = al_ustr_dup(al_path_ustr(p, '/'));
+   al_destroy_path(p);
    return us;
 }
 
@@ -76,7 +76,7 @@ static ALLEGRO_FS_ENTRY *fs_phys_create_entry(const char *path)
       return NULL;
    e->fs_entry.vtable = &fs_phys_vtable;
 
-   us = _al_physfs_apply_cwd(path);
+   us = _al_physfs_process_path(path);
    e->path = al_create_path(al_cstr(us));
    al_ustr_free(us);
    if (!e->path) {
@@ -101,6 +101,7 @@ static bool fs_phys_change_directory(const char *path)
 {
    ALLEGRO_USTR *us;
    bool ret;
+   PHYSFS_Stat stat;
 
    /* '/' root is guaranteed to exist but PHYSFS won't find it. */
    if (path[0] == '/' && path[1] == '\0') {
@@ -113,11 +114,14 @@ static bool fs_phys_change_directory(const char *path)
    if (path_is_absolute(path))
       us = al_ustr_new(path);
    else
-      us = _al_physfs_apply_cwd(path);
+      us = _al_physfs_process_path(path);
 
    ret = false;
 
-   if (PHYSFS_isDirectory(al_cstr(us))) {
+   if (!PHYSFS_stat(al_cstr(us), &stat))
+      return false;
+
+   if (stat.filetype == PHYSFS_FILETYPE_DIRECTORY ) {
       ensure_trailing_slash(us);
 
       /* Copy to static buffer. */
@@ -137,7 +141,7 @@ static bool fs_phys_filename_exists(const char *path)
    ALLEGRO_USTR *us;
    bool ret;
 
-   us = _al_physfs_apply_cwd(path);
+   us = _al_physfs_process_path(path);
    ret = PHYSFS_exists(al_cstr(us)) ? true : false;
    al_ustr_free(us);
    return ret;
@@ -148,7 +152,7 @@ static bool fs_phys_remove_filename(const char *path)
    ALLEGRO_USTR *us;
    bool ret;
 
-   us = _al_physfs_apply_cwd(path);
+   us = _al_physfs_process_path(path);
    ret = PHYSFS_delete(al_cstr(us)) ? true : false;
    al_ustr_free(us);
    return ret;
@@ -159,7 +163,7 @@ static bool fs_phys_make_directory(const char *path)
    ALLEGRO_USTR *us;
    bool ret;
 
-   us = _al_physfs_apply_cwd(path);
+   us = _al_physfs_process_path(path);
    ret = PHYSFS_mkdir(al_cstr(us)) ? true : false;
    al_ustr_free(us);
    return ret;
@@ -193,7 +197,11 @@ static uint32_t fs_phys_entry_mode(ALLEGRO_FS_ENTRY *fse)
 {
    ALLEGRO_FS_ENTRY_PHYSFS *e = (ALLEGRO_FS_ENTRY_PHYSFS *)fse;
    uint32_t mode = ALLEGRO_FILEMODE_READ;
-   if (PHYSFS_isDirectory(e->path_cstr))
+   PHYSFS_Stat stat;
+   if (!PHYSFS_stat(e->path_cstr, &stat))
+      return mode;
+
+   if (stat.filetype == PHYSFS_FILETYPE_DIRECTORY )
       mode |= ALLEGRO_FILEMODE_ISDIR | ALLEGRO_FILEMODE_EXECUTE;
    else
       mode |= ALLEGRO_FILEMODE_ISFILE;
@@ -203,7 +211,10 @@ static uint32_t fs_phys_entry_mode(ALLEGRO_FS_ENTRY *fse)
 static time_t fs_phys_entry_mtime(ALLEGRO_FS_ENTRY *fse)
 {
    ALLEGRO_FS_ENTRY_PHYSFS *e = (ALLEGRO_FS_ENTRY_PHYSFS *)fse;
-   return PHYSFS_getLastModTime(e->path_cstr);
+   PHYSFS_Stat stat;
+   if (!PHYSFS_stat(e->path_cstr, &stat))
+      return -1;
+   return stat.modtime;
 }
 
 static bool fs_phys_entry_exists(ALLEGRO_FS_ENTRY *fse)
