@@ -3,6 +3,6 @@
 
 void _al_set_physfs_fs_interface(void);
 const ALLEGRO_FILE_INTERFACE *_al_get_phys_vtable(void);
-ALLEGRO_USTR *_al_physfs_apply_cwd(const char *path);
+ALLEGRO_USTR *_al_physfs_process_path(const char *path);
 
 #endif
