@@ -2,12 +2,11 @@
 #include <stdlib.h>
 #include <math.h>
 #include "allegro5/allegro.h"
-#include "allegro5/allegro_image.h"
 #include "allegro5/allegro_font.h"
 
 #include "common.c"
 
-int main(void)
+int main(int argc, char **argv)
 {
    ALLEGRO_DISPLAY *display;
    ALLEGRO_BITMAP *tex1, *tex2;
@@ -19,10 +18,12 @@ int main(void)
    unsigned char *p;
    int x, y;
 
+   (void)argc;
+   (void)argv;
+
    if (!al_init()) {
       abort_example("Could not init Allegro.\n");
    }
-   al_init_image_addon();
    al_init_font_addon();
 
    al_install_mouse();
@@ -33,7 +34,7 @@ int main(void)
       abort_example("Error creating display\n");
    }
 
-   font = al_load_font("data/fixed_font.tga", 0, 0);
+   font = al_create_builtin_font();
 
    tex1 = al_create_bitmap(8, 8);
    lock = al_lock_bitmap(tex1, ALLEGRO_PIXEL_FORMAT_ABGR_8888_LE, ALLEGRO_LOCK_WRITEONLY);
@@ -96,13 +97,13 @@ int main(void)
 
          redraw = false;
          al_clear_to_color(al_map_rgb_f(0.5, 0.6, 1));
-         
+
          al_set_blender(ALLEGRO_ADD, ALLEGRO_ONE, ALLEGRO_INVERSE_ALPHA);
          al_draw_textf(font, color, x, y, 0, "not premultiplied");
          al_draw_textf(font, color, x, y + th, 0, "no filtering");
          al_set_blender(ALLEGRO_ADD, ALLEGRO_ALPHA, ALLEGRO_INVERSE_ALPHA);
          al_draw_scaled_rotated_bitmap(tex1, 4, 4, x + 320, y, 8, 8, a, 0);
-         
+
          y += 120;
 
          al_set_blender(ALLEGRO_ADD, ALLEGRO_ONE, ALLEGRO_INVERSE_ALPHA);
@@ -120,7 +121,7 @@ int main(void)
          al_draw_textf(font, color, x + 400, y, 0, "no difference");
          al_set_blender(ALLEGRO_ADD, ALLEGRO_ONE, ALLEGRO_INVERSE_ALPHA);
          al_draw_scaled_rotated_bitmap(tex1, 4, 4, x + 320, y, 8, 8, a, 0);
-         
+
          y += 120;
 
          al_set_blender(ALLEGRO_ADD, ALLEGRO_ONE, ALLEGRO_INVERSE_ALPHA);
@@ -134,7 +135,7 @@ int main(void)
       }
    }
 
-   al_destroy_font(font); 
+   al_destroy_font(font);
    al_destroy_bitmap(tex1);
    al_destroy_bitmap(tex2);
 
