@@ -3,7 +3,6 @@
  */
 #include <allegro5/allegro.h>
 #include <allegro5/allegro_font.h>
-#include <allegro5/allegro_image.h>
 #include <allegro5/allegro_primitives.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -36,9 +35,9 @@ static void init(void)
    ex.FPS = 50;
    ex.first_tick = true;
 
-   ex.myfont = al_load_font("data/fixed_font.tga", 0, 0);
+   ex.myfont = al_create_builtin_font();
    if (!ex.myfont) {
-      abort_example("data/fixed_font.tga not found\n");
+      abort_example("Error creating builtin font\n");
    }
 }
 
@@ -68,7 +67,7 @@ static void draw(void)
 {
    int h, y, i;
    double cur_time, event_overhead, total_error;
-   
+
    cur_time = al_get_time();
    event_overhead = cur_time - ex.timestamp;
    total_error = event_overhead + ex.timer_error;
@@ -161,19 +160,21 @@ static void run(void)
    }
 }
 
-int main(void)
+int main(int argc, char **argv)
 {
    ALLEGRO_DISPLAY *display;
    ALLEGRO_TIMER *timer;
 
+   (void)argc;
+   (void)argv;
+
    if (!al_init()) {
       abort_example("Could not init Allegro.\n");
    }
-   
+
    al_init_primitives_addon();
    al_install_keyboard();
    al_install_mouse();
-   al_init_image_addon();
    al_init_font_addon();
 
    display = al_create_display(640, 480);
