@@ -1,4 +1,4 @@
-#define ALLEGRO_CFG_WANT_NATIVE_IMAGE_LOADER
+/* #define ALLEGRO_CFG_WANT_NATIVE_IMAGE_LOADER */
 
 /* which libraries are present and needed? */
 /* #undef ALLEGRO_CFG_IIO_HAVE_GDIPLUS */
@@ -7,6 +7,8 @@
 /* #undef ALLEGRO_CFG_IIO_HAVE_PNG */
 /* #undef ALLEGRO_CFG_IIO_HAVE_JPG */
 
+#define ALLEGRO_CFG_IIO_HAVE_PNG
+
 /* which formats are supported and wanted? */
 #define ALLEGRO_CFG_IIO_SUPPORT_PNG
-#define ALLEGRO_CFG_IIO_SUPPORT_JPG
+//#define ALLEGRO_CFG_IIO_SUPPORT_JPG
