@@ -25,6 +25,8 @@
 #include "allegro5/internal/aintern_keyboard.h"
 #include "allegro5/platform/aintosx.h"
 
+#import <Carbon/Carbon.h>
+
 #ifndef ALLEGRO_MACOSX
 #error Something is wrong with the makefile
 #endif
@@ -49,6 +51,7 @@ static void osx_keyboard_exit(void);
 static ALLEGRO_KEYBOARD* osx_get_keyboard(void);
 static ALLEGRO_KEYBOARD keyboard;
 static ALLEGRO_KEYBOARD_STATE kbdstate;
+static UInt32 dead_key_state;
 
 
 
@@ -105,10 +108,8 @@ static void _handle_key_press(ALLEGRO_DISPLAY* dpy, int unicode, int scancode,
          if (!is_repeat) {
             _al_event_source_emit_event(&keyboard.es, &event);
          }
-         if (unicode > 0) {
-            /* Apple maps function, arrow, and other keys to Unicode points. */
-            /* http://www.unicode.org/Public/MAPPINGS/VENDORS/APPLE/CORPCHAR.TXT */
-            if (unicode >= 0xF700 && unicode <= 0xF747) {
+         if (unicode != 0) {
+            if (unicode < 0) {
                unicode = 0;
             }
             event.keyboard.type = ALLEGRO_EVENT_KEY_CHAR;
@@ -154,7 +155,7 @@ static const int mac_to_scancode[128] =
 {
    /* 0x00 */ ALLEGRO_KEY_A,        ALLEGRO_KEY_S,          ALLEGRO_KEY_D,          ALLEGRO_KEY_F,
    /* 0x04 */ ALLEGRO_KEY_H,        ALLEGRO_KEY_G,          ALLEGRO_KEY_Z,          ALLEGRO_KEY_X,
-   /* 0x08 */ ALLEGRO_KEY_C,        ALLEGRO_KEY_V,          0,                      ALLEGRO_KEY_B,
+   /* 0x08 */ ALLEGRO_KEY_C,        ALLEGRO_KEY_V,          ALLEGRO_KEY_BACKSLASH2, ALLEGRO_KEY_B,
    /* 0x0c */ ALLEGRO_KEY_Q,        ALLEGRO_KEY_W,          ALLEGRO_KEY_E,          ALLEGRO_KEY_R,
    /* 0x10 */ ALLEGRO_KEY_Y,        ALLEGRO_KEY_T,          ALLEGRO_KEY_1,          ALLEGRO_KEY_2,
    /* 0x14 */ ALLEGRO_KEY_3,        ALLEGRO_KEY_4,          ALLEGRO_KEY_6,          ALLEGRO_KEY_5,
@@ -168,7 +169,7 @@ static const int mac_to_scancode[128] =
    /* 0x34 */ ALLEGRO_KEY_ENTER,    ALLEGRO_KEY_ESCAPE,     0,                      ALLEGRO_KEY_COMMAND,
    /* 0x38 */ ALLEGRO_KEY_LSHIFT,   ALLEGRO_KEY_CAPSLOCK,   ALLEGRO_KEY_ALT,        ALLEGRO_KEY_LEFT,
    /* 0x3c */ ALLEGRO_KEY_RIGHT,    ALLEGRO_KEY_DOWN,       ALLEGRO_KEY_UP,         0,
-   /* 0x40 */ 0,                    ALLEGRO_KEY_FULLSTOP,   0,                      ALLEGRO_KEY_PAD_ASTERISK,
+   /* 0x40 */ 0,                    ALLEGRO_KEY_PAD_DELETE, 0,                      ALLEGRO_KEY_PAD_ASTERISK,
    /* 0x44 */ 0,                    ALLEGRO_KEY_PAD_PLUS,   0,                      ALLEGRO_KEY_NUMLOCK,
    /* 0x48 */ 0,                    0,                      0,                      ALLEGRO_KEY_PAD_SLASH,
    /* 0x4c */ ALLEGRO_KEY_PAD_ENTER,0,                      ALLEGRO_KEY_PAD_MINUS,  0,
@@ -262,21 +263,91 @@ void _al_osx_keyboard_handler(int pressed, NSEvent *event, ALLEGRO_DISPLAY* dpy)
     * lock is on (ie, letters are upper case)
     */
    int scancode = mac_to_scancode[[event keyCode]];
-   
+
    /* Translate OS X modifier flags to Allegro modifier flags */
    int key_shifts = translate_modifier_flags([event modifierFlags]);
 
-   if (pressed) {     
-      NSString* raw_characters = [event charactersIgnoringModifiers];
-      NSString* upper_characters = [event characters];
-      const unichar raw_character = ([raw_characters length] > 0) ? [raw_characters characterAtIndex: 0] : 0;
-      const unichar upper_character =([upper_characters length] > 0) ?  [upper_characters characterAtIndex: 0] : 0;
-      bool is_repeat = pressed ? ([event isARepeat] == YES) : false;
-      /* Special processing to send character 1 for CTRL-A, 2 for CTRL-B etc. */
-      if ((key_shifts & ALLEGRO_KEYMOD_CTRL) && (isalpha(raw_character)))
-         _handle_key_press(dpy, tolower(raw_character) - 'a' + 1, scancode, key_shifts, is_repeat);
+   if (pressed) {
+      int32_t unichar = 0;
+      bool new_input = _al_get_keyboard_compat_version() >= AL_ID(5, 2, 10, 0);
+      NSString *characters = [event characters];
+      UniChar character = ([characters length] > 0) ? [characters characterAtIndex: 0] : 0;
+
+      if (new_input) {
+         /* https://stackoverflow.com/a/22677690 */
+         TISInputSourceRef keyboard_input = TISCopyCurrentKeyboardInputSource();
+         CFDataRef layout_data = TISGetInputSourceProperty(keyboard_input, kTISPropertyUnicodeKeyLayoutData);
+         /* https://github.com/microsoft/vscode/issues/23833 */
+         if (!layout_data) {
+            /* TISGetInputSourceProperty returns null with a Japanese keyboard layout.
+             * Using TISCopyCurrentKeyboardLayoutInputSource to fix the NULL return.
+             */
+            keyboard_input = TISCopyCurrentKeyboardLayoutInputSource();
+            layout_data = TISGetInputSourceProperty(keyboard_input, kTISPropertyUnicodeKeyLayoutData);
+         }
+         const UCKeyboardLayout *layout = (const UCKeyboardLayout *)CFDataGetBytePtr(layout_data);
+
+         CGEventFlags modifier_flags = [event modifierFlags];
+         UInt32 modifier_key_state = (modifier_flags >> 16) & 0xff;
+
+         UniChar unicode_string[5];
+         unicode_string[4] = 0;
+         UniCharCount unicode_length;
+
+         UCKeyTranslate(layout,
+                        [event keyCode],
+                        kUCKeyActionDown,
+                        modifier_key_state,
+                        LMGetKbdType(),
+                        0,
+                        &dead_key_state,
+                        4,
+                        &unicode_length,
+                        unicode_string);
+         if (unicode_length > 0) {
+            ALLEGRO_USTR *ustr = al_ustr_new_from_utf16(unicode_string);
+            /* TODO: Possibly add an option to emit multiple events here.
+             * At the moment, we take the last key, because when an invalid
+             * dead key combination is entered, unicode string contains a character
+             * representaiton of the dead key + the last pressed key.
+             * We opt to return the last pressed key.
+             */
+            unichar = al_ustr_get(ustr, al_ustr_offset(ustr, (int)unicode_length - 1));
+            if (unichar < 0)
+               unichar = 0;
+            /* For some reason, pad enter sends a ^C. */
+            else if (scancode == ALLEGRO_KEY_PAD_ENTER && unichar == 3)
+               unichar = '\r';
+            /* This is here to override the Ctrl/Cmd fixes for backspace. */
+            else if (scancode == ALLEGRO_KEY_BACKSPACE)
+               unichar = '\b';
+            /* For some reason, Ctrl-<key> sends capital version of the character,
+               and not the correct invisible character. */
+            else if (key_shifts & ALLEGRO_KEYMOD_CTRL)
+               unichar = character;
+            /* For some reason, Cmd-<key> converts characters to Ctrl-<key>. */
+            else if (key_shifts & ALLEGRO_KEYMOD_COMMAND)
+               unichar = character;
+            al_ustr_free(ustr);
+         }
+         CFRelease(keyboard_input);
+      }
       else
-         _handle_key_press(dpy, upper_character, scancode, key_shifts, is_repeat);
+         unichar = character;
+
+      /* Apple maps function, arrow, and other keys to Unicode points.
+         https://www.unicode.org/Public/MAPPINGS/VENDORS/APPLE/CORPCHAR.TXT
+         We want to generate CHAR events for them, so we'll override the translation logic.
+        _handle_key_press will set the unichar back to 0 for these keys. */
+      if (character >= 0xF700 && character <= 0xF747) {
+         /* The old input did not handle this key (delete) correctly. We preserve the old behavior. */
+         if (new_input && character == 0xF728)
+            unichar = 127;
+         else
+            unichar = -1;
+      }
+      bool is_repeat = pressed ? ([event isARepeat] == YES) : false;
+      _handle_key_press(dpy, unichar, scancode, key_shifts, is_repeat);
    }
    else {
       _handle_key_release(dpy, key_shifts, scancode);
@@ -301,7 +372,7 @@ void _al_osx_keyboard_modifiers(unsigned int modifiers, ALLEGRO_DISPLAY* dpy)
       changed = (modifiers ^ old_modifiers) & mod_info[i][0];
       if (changed) {
          if (modifiers & mod_info[i][0]) {
-            _handle_key_press(dpy, -1, mod_info[i][2], key_shifts, false);
+            _handle_key_press(dpy, 0, mod_info[i][2], key_shifts, false);
             if (i == 0) {
                /* Caps lock requires special handling */
                _handle_key_release(dpy, key_shifts, mod_info[0][2]);
@@ -309,9 +380,9 @@ void _al_osx_keyboard_modifiers(unsigned int modifiers, ALLEGRO_DISPLAY* dpy)
          }
          else {
             if (i == 0) {
-               _handle_key_press(dpy, -1, mod_info[0][2], key_shifts, false);
+               _handle_key_press(dpy, 0, mod_info[0][2], key_shifts, false);
             }
-            
+
             _handle_key_release(dpy, key_shifts, mod_info[i][2]);
          }
       }
