@@ -31,8 +31,6 @@ ALLEGRO_STATIC_ASSERT(utime,
 /* Marks the time Allegro was initialised, for al_get_time(). */
 struct timespec _al_unix_initial_time;
 
-
-
 /* clock_gettime() doesn't exist in MacOSX versions < 10.12. Use
  * gettimeofday() if building for MacOSX and targeting version < 10.12.
  */
@@ -53,6 +51,15 @@ int _internal_clock_gettime(clockid_t clock_id, struct timespec* t)
 #define _al_clock_gettime clock_gettime
 #endif
 
+// Prefer clock that never decreases and includes time suspended.
+// Can probably use CLOCK_MONOTONIC_RAW for non-mac too, but remains to be
+// verified.
+#if defined(ALLEGRO_MACOSX)
+#define CLOCK_ID CLOCK_MONOTONIC_RAW
+#else
+#define CLOCK_ID CLOCK_REALTIME
+#endif
+
 
 
 /* _al_unix_init_time:
@@ -60,7 +67,7 @@ int _internal_clock_gettime(clockid_t clock_id, struct timespec* t)
  */
 void _al_unix_init_time(void)
 {
-   _al_clock_gettime(CLOCK_REALTIME, &_al_unix_initial_time);
+   _al_clock_gettime(CLOCK_ID, &_al_unix_initial_time);
 }
 
 
@@ -70,7 +77,7 @@ double _al_unix_get_time(void)
    struct timespec now;
    double time;
 
-   _al_clock_gettime(CLOCK_REALTIME, &now);
+   _al_clock_gettime(CLOCK_ID, &now);
    time = (double) (now.tv_sec - _al_unix_initial_time.tv_sec)
       + (double) (now.tv_nsec - _al_unix_initial_time.tv_nsec) * 1.0e-9;
    return time;
